@@ -9,7 +9,7 @@ Mojolicious::Plugin::AssetPack::Preprocessor::Scss - Preprocessor for .scss file
 =head1 DESCRIPTION
 
 L<Mojolicious::Plugin::AssetPack::Preprocessor::Scss> is a preprocessor for
-C<.scss> files. This module inherite all the functionality from
+C<.scss> files. This module inherits all the functionality from
 L<Mojolicious::Plugin::AssetPack::Preprocessor::Sass>.
 
 You need either the "sass" executable or the cpan module L<CSS::Sass> to make
@@ -31,7 +31,7 @@ The environment variable C<SASS_PATH> can be used to instruct this module
 to search for C<@import> files in directories other than relative to the
 the file containing the C<@import> statement.
 
-Note that C<SASS_PATH> need to hold absolute paths to work properly.
+Note that C<SASS_PATH> needs to hold absolute paths to work properly.
 
 Example usage:
 
@@ -188,8 +188,10 @@ sub _import_path {
   my ($ext, $name, $path) = (pop @rel, pop @rel);
 
   for my $p (map { File::Spec->catdir($_, @rel) } @$include_paths) {
-    return $path if -r ($path = catfile $p, "$name.$ext");
-    return $path if -r ($path = catfile $p, "_$name.$ext");
+    for ("$name.$ext", "_$name.$ext", $name, "_$name") {
+      my $f = catfile $p, $_;
+      return $f if -f $f and -r _;
+    }
   }
 
   if (DEBUG == 2) { local $" = '/'; warn "[ASSETPACK] Not found \@import @rel/$name.$ext\n" }
